@@ -1,8 +1,9 @@
 from .errors import SRTError, SRTLoginError, SRTNotLoggedInError, SRTResponseError
 from .passenger import Adult, Child, Disability1To3, Disability4To6, Passenger, Senior
+from .seat_type import SeatType
 from .srt import SRT
 
-__version__ = "2.0.4"
+__version__ = "2.0.5"
 
 __all__ = [
     "SRT",
@@ -16,4 +17,5 @@ __all__ = [
     "Senior",
     "Disability1To3",
     "Disability4To6",
+    "SeatType",
 ]
